"use strict";
/**
 * Returns a new array containing the keys of the array or object.
 * @param source Either an array or an object
 * @signature
 *    R.keys(source)
 *    R.keys.strict(source)
 * @example
 *    R.keys(['x', 'y', 'z']) // => ['1', '2', '3']
 *    R.keys({ a: 'x', b: 'y', c: 'z' }) // => ['a', 'b', 'c']
 *    R.pipe(
 *      { a: 'x', b: 'y', c: 'z' },
 *      R.keys,
 *      R.first
 *    ) // => 'a'
 *    R.keys.strict({ a: 'x', b: 'y', 5: 'z' } as const ) // => ['a', 'b', '5'], typed Array<'a' | 'b' | '5'>
 * @pipeable
 * @strict
 * @category Object
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.keys = void 0;
function keys(source) {
    return Object.keys(source);
}
exports.keys = keys;
(function (keys) {
    function strict(source) {
        return keys(source);
    }
    keys.strict = strict;
})(keys = exports.keys || (exports.keys = {}));
