import { PredIndexed } from './_types';
/**
 * Returns the mean of the elements of an array using the provided predicate.
 * @param fn predicate function
 * @signature
 *   R.meanBy(fn)(array)
 *   R.meanBy.indexed(fn)(array)
 * @example
 *    R.pipe(
 *      [{a: 5}, {a: 1}, {a: 3}],
 *      R.meanBy(x => x.a)
 *    ) // 3
 * @data_last
 * @indexed
 * @category Array
 */
export declare function meanBy<T>(fn: (item: T) => number): (items: readonly T[]) => number;
/**
 * Returns the mean of the elements of an array using the provided predicate.
 * @param items the array
 * @param fn predicate function
 * @signature
 *   R.meanBy(array, fn)
 *   R.meanBy.indexed(array, fn)
 * @example
 *    R.meanBy(
 *      [{a: 5}, {a: 1}, {a: 3}],
 *      x => x.a
 *    ) // 3
 * @data_first
 * @indexed
 * @category Array
 */
export declare function meanBy<T>(items: readonly T[], fn: (item: T) => number): number;
export declare namespace meanBy {
    function indexed<T>(array: readonly T[], fn: PredIndexed<T, number>): number;
    function indexed<T>(fn: PredIndexed<T, number>): (array: readonly T[]) => number;
}
//# sourceMappingURL=meanBy.d.ts.map