import { LazyResult } from './_reduceLazy';
declare type IsEquals<TFirst, TSecond> = (a: TFirst, b: TSecond) => boolean;
/**
 * Excludes the values from `other` array.
 * Elements are compared by custom comparator isEquals.
 * @param array the source array
 * @param other the values to exclude
 * @param isEquals the comparator
 * @signature
 *    R.differenceWith(array, other, isEquals)
 * @example
 *    R.differenceWith(
 *      [{a: 1}, {a: 2}, {a: 3}, {a: 4}],
 *      [{a: 2}, {a: 5}, {a: 3}],
 *      R.equals,
 *    ) // => [{a: 1}, {a: 4}]
 * @data_first
 * @category Array
 * @pipeable
 */
export declare function differenceWith<TFirst, TSecond>(array: readonly TFirst[], other: readonly TSecond[], isEquals: IsEquals<TFirst, TSecond>): TFirst[];
/**
 * Excludes the values from `other` array.
 * Elements are compared by custom comparator isEquals.
 * @param other the values to exclude
 * @param isEquals the comparator
 * @signature
 *    R.differenceWith(other, isEquals)(array)
 * @example
 *    R.differenceWith(
 *      [{a: 2}, {a: 5}, {a: 3}],
 *      R.equals,
 *    )([{a: 1}, {a: 2}, {a: 3}, {a: 4}]) // => [{a: 1}, {a: 4}]
 *    R.pipe(
 *      [{a: 1}, {a: 2}, {a: 3}, {a: 4}, {a: 5}, {a: 6}], // only 4 iterations
 *      R.differenceWith([{a: 2}, {a: 3}], R.equals),
 *      R.take(2),
 *    ) // => [{a: 1}, {a: 4}]
 * @data_last
 * @category Array
 * @pipeable
 */
export declare function differenceWith<TFirst, TSecond>(other: readonly TSecond[], isEquals: IsEquals<TFirst, TSecond>): (array: readonly TFirst[]) => TFirst[];
export declare namespace differenceWith {
    function lazy<TFirst, TSecond>(other: TSecond[], isEquals: IsEquals<TFirst, TSecond>): (value: TFirst) => LazyResult<TFirst>;
}
export {};
//# sourceMappingURL=differenceWith.d.ts.map